@@ -32,7 +32,7 @@ output_path = os.getcwd()
 verbose = True
 
 # A list of C++ reserved keywords which we need to handle
-cppKeywords = ['class', 'int', 'float', 'double']
+cppKeywords = ['class', 'int', 'float', 'double','long']
 
 def normalizeName(name):
     "Normalize a class or property name to be used as a C++ entity."
